@@ -5,7 +5,6 @@ from django.utils.translation import ugettext_lazy as _
 from django.db.models import get_model
 from django import forms
 
-from secureauth.defaults import CAPTCHA_ATTEMPT, CAPTCHA_ENABLED
 from secureauth.models import UserAuthAttempt, AUTH_TYPES
 from captcha.fields import CaptchaField
 
@@ -58,14 +57,17 @@ class ConfirmAuthenticationForm(forms.Form):
         return self.user_cache
 
 
-class AuthForm(AuthenticationForm):
-    def __init__(self, request=None, *args, **kwargs):
-        super(AuthForm, self).__init__(request, *args, **kwargs)
-        if UserAuthAttempt.get_obj(request).attempt > CAPTCHA_ATTEMPT:
-            self.fields['captcha'] = CaptchaField()
+class BaseAuthForm(AuthenticationForm):
+    def __init__(self, request, *args, **kwargs):
+        from secureauth.defaults import CAPTCHA_ATTEMPT, CAPTCHA_ENABLED
 
-    def is_valid(self):
-        return super(AuthForm, self).is_valid()
+        test_cookie_enabled = kwargs.pop('test_cookie_enabled', True)
 
+        super(BaseAuthForm, self).__init__(request, *args, **kwargs)
 
-BaseAuthForm = AuthForm if CAPTCHA_ENABLED else AuthenticationForm
+        if CAPTCHA_ENABLED is True:
+            if UserAuthAttempt.get_attempts(request) > CAPTCHA_ATTEMPT:
+                self.fields['captcha'] = CaptchaField()
+
+        if test_cookie_enabled is False:
+            self.request = None
